@@ -1,8 +1,9 @@
-use strict;
+#!/usr/bin/perl -w
+
 package Mail::Miner::Recogniser::Keywords;
 use Lingua::EN::Keywords;
 
-$Mail::Miner::recognisers{"".__PACKAGE__} =
+$Mail::Miner::recognisers{"".__PACKAGE__} = 
     {
      title => "Keywords",
      help  => "Match messages containing the given keywords",
