@@ -9,7 +9,7 @@ eval "use Mail::SpamAssassin";
 unless ($@) {
     $spamtest = Mail::SpamAssassin->new({local_tests_only => 1});
 
-    $Mail::Miner::recognisers{"".__PACKAGE__} =
+    $Mail::Miner::recognisers{"".__PACKAGE__} = 
         {
          title => "Spam",
          help  => "Tag a message with a spam score",
@@ -22,7 +22,7 @@ unless ($@) {
 sub process {
     my ($class, %hash) = @_;
     my $string = $hash{gethead}->()."\n".$hash{getbody}->();
-    if ($hash{gethead}->() =~ /X-Spam-Status: .*hits=(-?[\d\.]+)/) { return $1 }
+    if ($hash{gethead} =~ /X-Spam-Status: .*hits=(-?[\d\.]+)/) { return $1 }
     my $spamscore = $spamtest->check_message_text($string);
     my $score = $spamscore->get_hits;
     $spamscore->finish;
