@@ -1,6 +1,9 @@
-create sequence attachments_seq;
+DROP TABLE IF EXISTS attachments;
+DROP TABLE IF EXISTS messages;
+DROP TABLE IF EXISTS assets;
+
 create table attachments (
-    id integer NOT NULL default nextval('attachments_seq'),
+    id integer NOT NULL AUTO_INCREMENT,
     message_id integer NOT NULL,
     filename varchar(120),
     contenttype varchar(200),
@@ -9,9 +12,8 @@ create table attachments (
     PRIMARY KEY (id)
 );
 
-create sequence messages_seq;
 create table messages (
-    id integer NOT NULL default nextval('messages_seq'),
+    id integer NOT NULL AUTO_INCREMENT,
     from_address varchar(255),
     subject varchar(255),
     received DATETIME,
@@ -21,10 +23,10 @@ create table messages (
 create index message_from_ix on messages (from_address,id);
 create index subject_ix on messages (subject,id);
 
-create sequence assets_seq;
 create table assets (
-    message_id integer NOT NULL default nextval('assets_seq'),
-    creator varchar(30),
+    id integer NOT NULL PRIMARY KEY AUTO_INCREMENT,
+    message_id integer NOT NULL,
+    creator varchar(128),
     asset TEXT
 );
 create index creator_ix on assets (creator,message_id);
